@@ -25,6 +25,7 @@
 
 //KDE
 #include <kaboutdata.h>
+#include <KCrash>
 #include <KLocalizedString>
 #include <config-workspace.h>
 #include <KDBusService>
@@ -35,16 +36,16 @@
 KicApp::KicApp(int &argc, char **argv)
     : QApplication(argc, argv)
 {
-    QApplication::setApplicationDisplayName(i18n("KDE Info Center"));
+    const auto displayName = i18n("Info Center");
+    QApplication::setApplicationDisplayName(displayName);
     QApplication::setOrganizationDomain(QStringLiteral("kde.org"));
-
+    QApplication::setWindowIcon(QIcon::fromTheme("hwinfo"));
     KLocalizedString::setApplicationDomain("kinfocenter");
 
-    KAboutData aboutData( QStringLiteral("kinfocenter"), i18n("KDE Info Center"),
-        PROJECT_VERSION, i18n("The KDE Info Center"), KAboutLicense::GPL,
-        i18n("(c) 2009-2010, The KDE SC KInfocenter Development Team"));
+    KAboutData aboutData( QStringLiteral("kinfocenter"), displayName,
+        PROJECT_VERSION, displayName, KAboutLicense::GPL,
+        i18n("Copyright 2009-2016 KDE"));
 
-    aboutData.setProgramIconName(QStringLiteral("hwinfo"));
     aboutData.addAuthor(i18n("David Hubner"),i18n("Current Maintainer"), QStringLiteral("hubnerd@ntlworld.com"));
     aboutData.addAuthor(i18n("Helge Deller"), i18n("Previous Maintainer"), QStringLiteral("deller@kde.org"));
     aboutData.addAuthor(i18n("Matthias Hoelzer-Kluepfel"),QString(), QStringLiteral("hoelzer@kde.org"));
@@ -71,5 +72,7 @@ int main(int argc, char *argv[])
 {
     KicApp Kic(argc, argv);
 
+    KCrash::initialize();
+
     return Kic.exec();
 }
